/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED! */
#ifndef __PROC_BPF_SKEL_H__
#define __PROC_BPF_SKEL_H__

#include <stdlib.h>
#include <bpf/libbpf.h>

struct proc_bpf {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *__probe_match_map;
		struct bpf_map *args_map;
		struct bpf_map *cgrp_obj_map;
		struct bpf_map *g_proc_map;
		struct bpf_map *g_proc_output;
		struct bpf_map *g_thread_map;
		struct bpf_map *nm_obj_map;
		struct bpf_map *proc_exec_channel_map;
		struct bpf_map *proc_obj_map;
	} maps;
	struct {
		struct bpf_program *bpf_raw_trace_sched_process_exec;
	} progs;
	struct {
		struct bpf_link *bpf_raw_trace_sched_process_exec;
	} links;
};

static void
proc_bpf__destroy(struct proc_bpf *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
proc_bpf__create_skeleton(struct proc_bpf *obj);

static inline struct proc_bpf *
proc_bpf__open_opts(const struct bpf_object_open_opts *opts)
{
	struct proc_bpf *obj;

	obj = (struct proc_bpf *)calloc(1, sizeof(*obj));
	if (!obj)
		return NULL;
	if (proc_bpf__create_skeleton(obj))
		goto err;
	if (bpf_object__open_skeleton(obj->skeleton, opts))
		goto err;

	return obj;
err:
	proc_bpf__destroy(obj);
	return NULL;
}

static inline struct proc_bpf *
proc_bpf__open(void)
{
	return proc_bpf__open_opts(NULL);
}

static inline int
proc_bpf__load(struct proc_bpf *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct proc_bpf *
proc_bpf__open_and_load(void)
{
	struct proc_bpf *obj;

	obj = proc_bpf__open();
	if (!obj)
		return NULL;
	if (proc_bpf__load(obj)) {
		proc_bpf__destroy(obj);
		return NULL;
	}
	return obj;
}

static inline int
proc_bpf__attach(struct proc_bpf *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
proc_bpf__detach(struct proc_bpf *obj)
{
	return bpf_object__detach_skeleton(obj->skeleton);
}

static inline int
proc_bpf__create_skeleton(struct proc_bpf *obj)
{
	struct bpf_object_skeleton *s;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)
		return -1;
	obj->skeleton = s;

	s->sz = sizeof(*s);
	s->name = "proc_bpf";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 9;
	s->map_skel_sz = sizeof(*s->maps);
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt, s->map_skel_sz);
	if (!s->maps)
		goto err;

	s->maps[0].name = "__probe_match_map";
	s->maps[0].map = &obj->maps.__probe_match_map;

	s->maps[1].name = "args_map";
	s->maps[1].map = &obj->maps.args_map;

	s->maps[2].name = "cgrp_obj_map";
	s->maps[2].map = &obj->maps.cgrp_obj_map;

	s->maps[3].name = "g_proc_map";
	s->maps[3].map = &obj->maps.g_proc_map;

	s->maps[4].name = "g_proc_output";
	s->maps[4].map = &obj->maps.g_proc_output;

	s->maps[5].name = "g_thread_map";
	s->maps[5].map = &obj->maps.g_thread_map;

	s->maps[6].name = "nm_obj_map";
	s->maps[6].map = &obj->maps.nm_obj_map;

	s->maps[7].name = "proc_exec_channel_map";
	s->maps[7].map = &obj->maps.proc_exec_channel_map;

	s->maps[8].name = "proc_obj_map";
	s->maps[8].map = &obj->maps.proc_obj_map;

	/* programs */
	s->prog_cnt = 1;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs)
		goto err;

	s->progs[0].name = "bpf_raw_trace_sched_process_exec";
	s->progs[0].prog = &obj->progs.bpf_raw_trace_sched_process_exec;
	s->progs[0].link = &obj->links.bpf_raw_trace_sched_process_exec;

	s->data_sz = 4608;
	s->data = (void *)"\
\x7f\x45\x4c\x46\x02\x01\x01\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\xc0\x0e\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x0d\0\
\x0c\0\xbf\x16\0\0\0\0\0\0\xb7\x01\0\0\0\0\0\0\x63\x1a\xf8\xff\0\0\0\0\x7b\x1a\
\xf0\xff\0\0\0\0\x7b\x1a\xe8\xff\0\0\0\0\x7b\x1a\xe0\xff\0\0\0\0\x7b\x1a\xd8\
\xff\0\0\0\0\x7b\x1a\xd0\xff\0\0\0\0\x7b\x1a\xc8\xff\0\0\0\0\x7b\x1a\xc0\xff\0\
\0\0\0\x7b\x1a\xb8\xff\0\0\0\0\x7b\x1a\xb0\xff\0\0\0\0\x7b\x1a\xa8\xff\0\0\0\0\
\x7b\x1a\xa0\xff\0\0\0\0\x7b\x1a\x98\xff\0\0\0\0\x7b\x1a\x90\xff\0\0\0\0\x7b\
\x1a\x88\xff\0\0\0\0\x7b\x1a\x80\xff\0\0\0\0\x7b\x1a\x78\xff\0\0\0\0\x7b\x1a\
\x70\xff\0\0\0\0\x7b\x1a\x68\xff\0\0\0\0\x7b\x1a\x60\xff\0\0\0\0\x7b\x1a\x58\
\xff\0\0\0\0\x7b\x1a\x50\xff\0\0\0\0\x7b\x1a\x48\xff\0\0\0\0\x7b\x1a\x40\xff\0\
\0\0\0\x7b\x1a\x38\xff\0\0\0\0\x7b\x1a\x30\xff\0\0\0\0\x7b\x1a\x28\xff\0\0\0\0\
\x7b\x1a\x20\xff\0\0\0\0\x7b\x1a\x18\xff\0\0\0\0\x7b\x1a\x10\xff\0\0\0\0\x7b\
\x1a\x08\xff\0\0\0\0\x7b\x1a\0\xff\0\0\0\0\x7b\x1a\xf8\xfe\0\0\0\0\x85\0\0\0\
\x0e\0\0\0\x79\x67\x10\0\0\0\0\0\x79\x63\0\0\0\0\0\0\x07\x03\0\0\x10\x08\0\0\
\xbf\xa1\0\0\0\0\0\0\x07\x01\0\0\xf0\xfe\xff\xff\xb7\x02\0\0\x04\0\0\0\x85\0\0\
\0\x04\0\0\0\x61\xa8\xf0\xfe\0\0\0\0\x07\x07\0\0\x60\0\0\0\xbf\xa1\0\0\0\0\0\0\
\x07\x01\0\0\xf0\xfe\xff\xff\xb7\x02\0\0\x08\0\0\0\xbf\x73\0\0\0\0\0\0\x85\0\0\
\0\x04\0\0\0\x63\x8a\xf8\xff\0\0\0\0\x79\xa3\xf0\xfe\0\0\0\0\xbf\xa7\0\0\0\0\0\
\0\x07\x07\0\0\xf8\xfe\xff\xff\xbf\x71\0\0\0\0\0\0\xb7\x02\0\0\0\x01\0\0\x85\0\
\0\0\x04\0\0\0\xbf\x61\0\0\0\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x18\x03\
\0\0\xff\xff\xff\xff\0\0\0\0\0\0\0\0\xbf\x74\0\0\0\0\0\0\xb7\x05\0\0\x04\x01\0\
\0\x85\0\0\0\x19\0\0\0\x95\0\0\0\0\0\0\0\x01\0\0\0\x10\0\0\0\x30\0\0\0\xe8\x03\
\0\0\0\0\0\0\x01\0\0\0\x08\0\0\0\x04\0\0\0\x64\0\0\0\0\0\0\0\x01\0\0\0\x08\0\0\
\0\x04\0\0\0\x64\0\0\0\0\0\0\0\x01\0\0\0\x04\0\0\0\x04\0\0\0\xe8\x03\0\0\0\0\0\
\0\x02\0\0\0\x04\0\0\0\x10\0\0\0\x01\0\0\0\0\0\0\0\x01\0\0\0\x04\0\0\0\x68\0\0\
\0\xe8\x03\0\0\0\0\0\0\x01\0\0\0\x04\0\0\0\xd8\x01\0\0\xe8\x03\0\0\0\0\0\0\x04\
\0\0\0\x04\0\0\0\x04\0\0\0\x40\0\0\0\0\0\0\0\x04\0\0\0\x04\0\0\0\x04\0\0\0\x40\
\0\0\0\0\0\0\0\x47\x50\x4c\0\x9f\xeb\x01\0\x18\0\0\0\0\0\0\0\x38\x02\0\0\x38\
\x02\0\0\xe5\x03\0\0\0\0\0\0\0\0\0\x02\x02\0\0\0\x01\0\0\0\x01\0\0\x04\0\0\0\0\
\x19\0\0\0\x05\0\0\0\0\0\0\0\x1e\0\0\0\0\0\0\x08\x04\0\0\0\x24\0\0\0\0\0\0\x01\
\x08\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x03\0\0\0\x06\0\0\0\0\0\0\0\x3b\
\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\0\0\0\0\0\x01\0\0\x0d\0\0\0\0\x4f\0\0\0\x01\
\0\0\0\x53\0\0\0\x01\0\0\x0c\x07\0\0\0\x04\x03\0\0\x05\0\0\x04\x14\0\0\0\x10\
\x03\0\0\x0a\0\0\0\0\0\0\0\x15\x03\0\0\x0a\0\0\0\x20\0\0\0\x1e\x03\0\0\x0a\0\0\
\0\x40\0\0\0\x29\x03\0\0\x0a\0\0\0\x60\0\0\0\x35\x03\0\0\x0a\0\0\0\x80\0\0\0\
\x3f\x03\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\0\x4c\x03\0\0\0\0\0\x0e\x09\0\0\0\x01\
\0\0\0\x5e\x03\0\0\0\0\0\x0e\x09\0\0\0\x01\0\0\0\x6b\x03\0\0\0\0\0\x0e\x09\0\0\
\0\x01\0\0\0\x76\x03\0\0\0\0\0\x0e\x09\0\0\0\x01\0\0\0\x83\x03\0\0\0\0\0\x0e\
\x09\0\0\0\x01\0\0\0\x8c\x03\0\0\0\0\0\x0e\x09\0\0\0\x01\0\0\0\x99\x03\0\0\0\0\
\0\x0e\x09\0\0\0\x01\0\0\0\xa4\x03\0\0\0\0\0\x0e\x09\0\0\0\x01\0\0\0\xb2\x03\0\
\0\0\0\0\x01\x01\0\0\0\x08\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\x13\0\0\0\x06\0\0\
\0\x04\0\0\0\xb7\x03\0\0\0\0\0\x0e\x14\0\0\0\x01\0\0\0\xc2\x03\0\0\0\0\0\x0e\
\x09\0\0\0\x01\0\0\0\xd8\x03\0\0\x01\0\0\x0f\0\0\0\0\x15\0\0\0\0\0\0\0\x04\0\0\
\0\xe0\x03\0\0\x09\0\0\x0f\0\0\0\0\x0b\0\0\0\0\0\0\0\x14\0\0\0\x0c\0\0\0\0\0\0\
\0\x14\0\0\0\x0d\0\0\0\0\0\0\0\x14\0\0\0\x0e\0\0\0\0\0\0\0\x14\0\0\0\x0f\0\0\0\
\0\0\0\0\x14\0\0\0\x10\0\0\0\0\0\0\0\x14\0\0\0\x11\0\0\0\0\0\0\0\x14\0\0\0\x12\
\0\0\0\0\0\0\0\x14\0\0\0\x16\0\0\0\0\0\0\0\x14\0\0\0\0\x62\x70\x66\x5f\x72\x61\
\x77\x5f\x74\x72\x61\x63\x65\x70\x6f\x69\x6e\x74\x5f\x61\x72\x67\x73\0\x61\x72\
\x67\x73\0\x5f\x5f\x75\x36\x34\0\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\x67\x20\x75\
\x6e\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x5f\x5f\x41\x52\x52\x41\x59\x5f\
\x53\x49\x5a\x45\x5f\x54\x59\x50\x45\x5f\x5f\0\x63\x74\x78\0\x62\x70\x66\x5f\
\x72\x61\x77\x5f\x74\x72\x61\x63\x65\x5f\x73\x63\x68\x65\x64\x5f\x70\x72\x6f\
\x63\x65\x73\x73\x5f\x65\x78\x65\x63\0\x72\x61\x77\x5f\x74\x72\x61\x63\x65\x70\
\x6f\x69\x6e\x74\x2f\x73\x63\x68\x65\x64\x5f\x70\x72\x6f\x63\x65\x73\x73\x5f\
\x65\x78\x65\x63\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x72\x70\x6d\x62\x75\
\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x67\x61\x6c\x61\x2d\x67\x6f\x70\x68\
\x65\x72\x2d\x31\x2e\x30\x2e\x31\x2f\x73\x72\x63\x2f\x70\x72\x6f\x62\x65\x73\
\x2f\x65\x78\x74\x65\x6e\x64\x73\x2f\x65\x62\x70\x66\x2e\x70\x72\x6f\x62\x65\
\x2f\x73\x72\x63\x2f\x74\x61\x73\x6b\x70\x72\x6f\x62\x65\x2f\x70\x72\x6f\x63\
\x2e\x62\x70\x66\x2e\x63\0\x4b\x52\x41\x57\x54\x52\x41\x43\x45\x28\x73\x63\x68\
\x65\x64\x5f\x70\x72\x6f\x63\x65\x73\x73\x5f\x65\x78\x65\x63\x2c\x20\x62\x70\
\x66\x5f\x72\x61\x77\x5f\x74\x72\x61\x63\x65\x70\x6f\x69\x6e\x74\x5f\x61\x72\
\x67\x73\x29\0\x20\x20\x20\x20\x73\x74\x72\x75\x63\x74\x20\x70\x72\x6f\x63\x5f\
\x65\x78\x65\x63\x5f\x65\x76\x74\x20\x65\x76\x65\x6e\x74\x20\x3d\x20\x7b\x30\
\x7d\x3b\0\x20\x20\x20\x20\x75\x33\x32\x20\x70\x69\x64\x5f\x75\x6e\x75\x73\x65\
\x64\x20\x5f\x5f\x6d\x61\x79\x62\x65\x5f\x75\x6e\x75\x73\x65\x64\x20\x3d\x20\
\x62\x70\x66\x5f\x67\x65\x74\x5f\x63\x75\x72\x72\x65\x6e\x74\x5f\x70\x69\x64\
\x5f\x74\x67\x69\x64\x28\x29\x3b\0\x20\x20\x20\x20\x73\x74\x72\x75\x63\x74\x20\
\x6c\x69\x6e\x75\x78\x5f\x62\x69\x6e\x70\x72\x6d\x20\x2a\x62\x70\x72\x6d\x20\
\x3d\x20\x28\x73\x74\x72\x75\x63\x74\x20\x6c\x69\x6e\x75\x78\x5f\x62\x69\x6e\
\x70\x72\x6d\x20\x2a\x29\x63\x74\x78\x2d\x3e\x61\x72\x67\x73\x5b\x32\x5d\x3b\0\
\x20\x20\x20\x20\x73\x74\x72\x75\x63\x74\x20\x74\x61\x73\x6b\x5f\x73\x74\x72\
\x75\x63\x74\x2a\x20\x74\x61\x73\x6b\x20\x3d\x20\x28\x73\x74\x72\x75\x63\x74\
\x20\x74\x61\x73\x6b\x5f\x73\x74\x72\x75\x63\x74\x20\x2a\x29\x63\x74\x78\x2d\
\x3e\x61\x72\x67\x73\x5b\x30\x5d\x3b\0\x20\x20\x20\x20\x70\x69\x64\x5f\x74\x20\
\x70\x69\x64\x20\x3d\x20\x5f\x28\x74\x61\x73\x6b\x2d\x3e\x70\x69\x64\x29\x3b\0\
\x20\x20\x20\x20\x63\x6f\x6e\x73\x74\x20\x63\x68\x61\x72\x20\x2a\x66\x69\x6c\
\x65\x6e\x61\x6d\x65\x20\x3d\x20\x5f\x28\x62\x70\x72\x6d\x2d\x3e\x66\x69\x6c\
\x65\x6e\x61\x6d\x65\x29\x3b\0\x20\x20\x20\x20\x65\x76\x65\x6e\x74\x2e\x70\x69\
\x64\x20\x3d\x20\x28\x75\x33\x32\x29\x70\x69\x64\x3b\0\x20\x20\x20\x20\x62\x70\
\x66\x5f\x70\x72\x6f\x62\x65\x5f\x72\x65\x61\x64\x28\x26\x65\x76\x65\x6e\x74\
\x2e\x66\x69\x6c\x65\x6e\x61\x6d\x65\x2c\x20\x50\x41\x54\x48\x5f\x4c\x45\x4e\
\x2c\x20\x66\x69\x6c\x65\x6e\x61\x6d\x65\x29\x3b\0\x20\x20\x20\x20\x62\x70\x66\
\x5f\x70\x65\x72\x66\x5f\x65\x76\x65\x6e\x74\x5f\x6f\x75\x74\x70\x75\x74\x28\
\x63\x74\x78\x2c\x20\x26\x70\x72\x6f\x63\x5f\x65\x78\x65\x63\x5f\x63\x68\x61\
\x6e\x6e\x65\x6c\x5f\x6d\x61\x70\x2c\x20\x42\x50\x46\x5f\x46\x5f\x41\x4c\x4c\
\x5f\x43\x50\x55\x2c\0\x7d\0\x62\x70\x66\x5f\x6d\x61\x70\x5f\x64\x65\x66\0\x74\
\x79\x70\x65\0\x6b\x65\x79\x5f\x73\x69\x7a\x65\0\x76\x61\x6c\x75\x65\x5f\x73\
\x69\x7a\x65\0\x6d\x61\x78\x5f\x65\x6e\x74\x72\x69\x65\x73\0\x6d\x61\x70\x5f\
\x66\x6c\x61\x67\x73\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x5f\
\x5f\x70\x72\x6f\x62\x65\x5f\x6d\x61\x74\x63\x68\x5f\x6d\x61\x70\0\x63\x67\x72\
\x70\x5f\x6f\x62\x6a\x5f\x6d\x61\x70\0\x6e\x6d\x5f\x6f\x62\x6a\x5f\x6d\x61\x70\
\0\x70\x72\x6f\x63\x5f\x6f\x62\x6a\x5f\x6d\x61\x70\0\x61\x72\x67\x73\x5f\x6d\
\x61\x70\0\x67\x5f\x74\x68\x72\x65\x61\x64\x5f\x6d\x61\x70\0\x67\x5f\x70\x72\
\x6f\x63\x5f\x6d\x61\x70\0\x67\x5f\x70\x72\x6f\x63\x5f\x6f\x75\x74\x70\x75\x74\
\0\x63\x68\x61\x72\0\x67\x5f\x6c\x69\x6e\x73\x65\x6e\x63\x65\0\x70\x72\x6f\x63\
\x5f\x65\x78\x65\x63\x5f\x63\x68\x61\x6e\x6e\x65\x6c\x5f\x6d\x61\x70\0\x6c\x69\
\x63\x65\x6e\x73\x65\0\x6d\x61\x70\x73\0\x9f\xeb\x01\0\x20\0\0\0\0\0\0\0\x14\0\
\0\0\x14\0\0\0\x1c\x01\0\0\x30\x01\0\0\0\0\0\0\x08\0\0\0\x74\0\0\0\x01\0\0\0\0\
\0\0\0\x08\0\0\0\x10\0\0\0\x74\0\0\0\x11\0\0\0\0\0\0\0\x96\0\0\0\xf8\0\0\0\0\
\xa0\0\0\x10\0\0\0\x96\0\0\0\x2f\x01\0\0\x1a\xa8\0\0\x18\x01\0\0\x96\0\0\0\x55\
\x01\0\0\x25\xac\0\0\x20\x01\0\0\x96\0\0\0\x95\x01\0\0\x38\xb4\0\0\x28\x01\0\0\
\x96\0\0\0\xda\x01\0\0\x36\xb0\0\0\x30\x01\0\0\x96\0\0\0\x1d\x02\0\0\x11\xb8\0\
\0\x40\x01\0\0\x96\0\0\0\0\0\0\0\0\0\0\0\x48\x01\0\0\x96\0\0\0\x1d\x02\0\0\x11\
\xb8\0\0\x60\x01\0\0\x96\0\0\0\x3b\x02\0\0\x1c\xbc\0\0\x70\x01\0\0\x96\0\0\0\0\
\0\0\0\0\0\0\0\x78\x01\0\0\x96\0\0\0\x3b\x02\0\0\x1c\xbc\0\0\x90\x01\0\0\x96\0\
\0\0\x69\x02\0\0\x0f\xc4\0\0\x98\x01\0\0\x96\0\0\0\x3b\x02\0\0\x1c\xbc\0\0\xa8\
\x01\0\0\x96\0\0\0\0\0\0\0\0\0\0\0\xb0\x01\0\0\x96\0\0\0\x83\x02\0\0\x05\xc8\0\
\0\xc8\x01\0\0\x96\0\0\0\xbc\x02\0\0\x05\xd0\0\0\x08\x02\0\0\x96\0\0\0\x02\x03\
\0\0\x01\xd8\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x03\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x6b\0\0\0\x11\0\x03\0\0\0\0\0\0\0\
\0\0\x14\0\0\0\0\0\0\0\x27\0\0\0\x11\0\x03\0\x50\0\0\0\0\0\0\0\x14\0\0\0\0\0\0\
\0\xb6\0\0\0\x12\0\x02\0\0\0\0\0\0\0\0\0\x10\x02\0\0\0\0\0\0\x46\0\0\0\x11\0\
\x03\0\x14\0\0\0\0\0\0\0\x14\0\0\0\0\0\0\0\xab\0\0\0\x11\0\x04\0\0\0\0\0\0\0\0\
\0\x04\0\0\0\0\0\0\0\x8a\0\0\0\x11\0\x03\0\x78\0\0\0\0\0\0\0\x14\0\0\0\0\0\0\0\
\x14\0\0\0\x11\0\x03\0\x8c\0\0\0\0\0\0\0\x14\0\0\0\0\0\0\0\x7d\0\0\0\x11\0\x03\
\0\x64\0\0\0\0\0\0\0\x14\0\0\0\0\0\0\0\x53\0\0\0\x11\0\x03\0\x28\0\0\0\0\0\0\0\
\x14\0\0\0\0\0\0\0\x30\0\0\0\x11\0\x03\0\xa0\0\0\0\0\0\0\0\x14\0\0\0\0\0\0\0\
\x5e\0\0\0\x11\0\x03\0\x3c\0\0\0\0\0\0\0\x14\0\0\0\0\0\0\0\xd0\x01\0\0\0\0\0\0\
\x01\0\0\0\x0b\0\0\0\xd0\x01\0\0\0\0\0\0\0\0\0\0\x06\0\0\0\xe8\x01\0\0\0\0\0\0\
\0\0\0\0\x02\0\0\0\xf4\x01\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\0\x02\0\0\0\0\0\0\0\0\
\0\0\x0a\0\0\0\x0c\x02\0\0\0\0\0\0\0\0\0\0\x0c\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\
\0\x03\0\0\0\x24\x02\0\0\0\0\0\0\0\0\0\0\x09\0\0\0\x30\x02\0\0\0\0\0\0\0\0\0\0\
\x07\0\0\0\x3c\x02\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\x48\x02\0\0\0\0\0\0\0\0\0\0\
\x0b\0\0\0\x2c\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\x01\0\
\0\0\x50\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x60\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\
\x70\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x80\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x90\0\
\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\xa0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\xb0\0\0\0\0\
\0\0\0\0\0\0\0\x01\0\0\0\xc0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\xd0\0\0\0\0\0\0\0\
\0\0\0\0\x01\0\0\0\xe0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\xf0\0\0\0\0\0\0\0\0\0\0\
\0\x01\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x10\x01\0\0\0\0\0\0\0\0\0\0\
\x01\0\0\0\x20\x01\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x30\x01\0\0\0\0\0\0\0\0\0\0\
\x01\0\0\0\x40\x01\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x0b\x09\x0c\x11\x13\x0a\x10\
\x0e\x0f\x0d\x12\0\x2e\x74\x65\x78\x74\0\x2e\x72\x65\x6c\x2e\x42\x54\x46\x2e\
\x65\x78\x74\0\x67\x5f\x70\x72\x6f\x63\x5f\x6f\x75\x74\x70\x75\x74\0\x6d\x61\
\x70\x73\0\x61\x72\x67\x73\x5f\x6d\x61\x70\0\x70\x72\x6f\x63\x5f\x65\x78\x65\
\x63\x5f\x63\x68\x61\x6e\x6e\x65\x6c\x5f\x6d\x61\x70\0\x63\x67\x72\x70\x5f\x6f\
\x62\x6a\x5f\x6d\x61\x70\0\x6e\x6d\x5f\x6f\x62\x6a\x5f\x6d\x61\x70\0\x70\x72\
\x6f\x63\x5f\x6f\x62\x6a\x5f\x6d\x61\x70\0\x5f\x5f\x70\x72\x6f\x62\x65\x5f\x6d\
\x61\x74\x63\x68\x5f\x6d\x61\x70\0\x67\x5f\x74\x68\x72\x65\x61\x64\x5f\x6d\x61\
\x70\0\x67\x5f\x70\x72\x6f\x63\x5f\x6d\x61\x70\0\x2e\x6c\x6c\x76\x6d\x5f\x61\
\x64\x64\x72\x73\x69\x67\0\x6c\x69\x63\x65\x6e\x73\x65\0\x67\x5f\x6c\x69\x6e\
\x73\x65\x6e\x63\x65\0\x62\x70\x66\x5f\x72\x61\x77\x5f\x74\x72\x61\x63\x65\x5f\
\x73\x63\x68\x65\x64\x5f\x70\x72\x6f\x63\x65\x73\x73\x5f\x65\x78\x65\x63\0\x2e\
\x72\x65\x6c\x72\x61\x77\x5f\x74\x72\x61\x63\x65\x70\x6f\x69\x6e\x74\x2f\x73\
\x63\x68\x65\x64\x5f\x70\x72\x6f\x63\x65\x73\x73\x5f\x65\x78\x65\x63\0\x2e\x73\
\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x2e\x72\x65\x6c\x2e\x42\
\x54\x46\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\
\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xdb\0\0\0\x01\0\0\0\
\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\x10\x02\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x22\0\0\0\x01\0\0\0\x03\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x50\x02\0\0\0\0\0\0\xb4\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xa3\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x04\x03\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x11\x01\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\x03\
\0\0\0\0\0\0\x35\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x0b\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x3d\x09\0\0\0\0\0\0\
\x50\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x05\x01\
\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x90\x0a\0\0\0\0\0\0\x38\x01\0\0\
\0\0\0\0\x0c\0\0\0\x02\0\0\0\x08\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\0\xd7\0\0\0\x09\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xc8\x0b\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\
\x07\0\0\0\x02\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x0d\x01\0\0\x09\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xd8\x0b\0\0\0\0\0\0\xa0\0\0\0\0\0\0\0\x07\0\0\
\0\x05\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x07\0\0\0\x09\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x78\x0c\0\0\0\0\0\0\x20\x01\0\0\0\0\0\0\x07\0\0\0\x06\0\
\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x95\0\0\0\x03\x4c\xff\x6f\0\0\0\x80\0\
\0\0\0\0\0\0\0\0\0\0\0\x98\x0d\0\0\0\0\0\0\x0b\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xfd\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\xa3\x0d\0\0\0\0\0\0\x16\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0";

	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return -1;
}

#endif /* __PROC_BPF_SKEL_H__ */
