/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED! */
#ifndef __THREAD_BPF_SKEL_H__
#define __THREAD_BPF_SKEL_H__

#include <stdlib.h>
#include <bpf/libbpf.h>

struct thread_bpf {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *__probe_match_map;
		struct bpf_map *args_map;
		struct bpf_map *cgrp_obj_map;
		struct bpf_map *g_proc_map;
		struct bpf_map *g_thread_map;
		struct bpf_map *g_thread_output;
		struct bpf_map *nm_obj_map;
		struct bpf_map *proc_obj_map;
	} maps;
	struct {
		struct bpf_program *bpf_raw_trace_sched_wakeup_new;
	} progs;
	struct {
		struct bpf_link *bpf_raw_trace_sched_wakeup_new;
	} links;
};

static void
thread_bpf__destroy(struct thread_bpf *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
thread_bpf__create_skeleton(struct thread_bpf *obj);

static inline struct thread_bpf *
thread_bpf__open_opts(const struct bpf_object_open_opts *opts)
{
	struct thread_bpf *obj;

	obj = (struct thread_bpf *)calloc(1, sizeof(*obj));
	if (!obj)
		return NULL;
	if (thread_bpf__create_skeleton(obj))
		goto err;
	if (bpf_object__open_skeleton(obj->skeleton, opts))
		goto err;

	return obj;
err:
	thread_bpf__destroy(obj);
	return NULL;
}

static inline struct thread_bpf *
thread_bpf__open(void)
{
	return thread_bpf__open_opts(NULL);
}

static inline int
thread_bpf__load(struct thread_bpf *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct thread_bpf *
thread_bpf__open_and_load(void)
{
	struct thread_bpf *obj;

	obj = thread_bpf__open();
	if (!obj)
		return NULL;
	if (thread_bpf__load(obj)) {
		thread_bpf__destroy(obj);
		return NULL;
	}
	return obj;
}

static inline int
thread_bpf__attach(struct thread_bpf *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
thread_bpf__detach(struct thread_bpf *obj)
{
	return bpf_object__detach_skeleton(obj->skeleton);
}

static inline int
thread_bpf__create_skeleton(struct thread_bpf *obj)
{
	struct bpf_object_skeleton *s;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)
		return -1;
	obj->skeleton = s;

	s->sz = sizeof(*s);
	s->name = "thread_bpf";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 8;
	s->map_skel_sz = sizeof(*s->maps);
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt, s->map_skel_sz);
	if (!s->maps)
		goto err;

	s->maps[0].name = "__probe_match_map";
	s->maps[0].map = &obj->maps.__probe_match_map;

	s->maps[1].name = "args_map";
	s->maps[1].map = &obj->maps.args_map;

	s->maps[2].name = "cgrp_obj_map";
	s->maps[2].map = &obj->maps.cgrp_obj_map;

	s->maps[3].name = "g_proc_map";
	s->maps[3].map = &obj->maps.g_proc_map;

	s->maps[4].name = "g_thread_map";
	s->maps[4].map = &obj->maps.g_thread_map;

	s->maps[5].name = "g_thread_output";
	s->maps[5].map = &obj->maps.g_thread_output;

	s->maps[6].name = "nm_obj_map";
	s->maps[6].map = &obj->maps.nm_obj_map;

	s->maps[7].name = "proc_obj_map";
	s->maps[7].map = &obj->maps.proc_obj_map;

	/* programs */
	s->prog_cnt = 1;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs)
		goto err;

	s->progs[0].name = "bpf_raw_trace_sched_wakeup_new";
	s->progs[0].prog = &obj->progs.bpf_raw_trace_sched_wakeup_new;
	s->progs[0].link = &obj->links.bpf_raw_trace_sched_wakeup_new;

	s->data_sz = 7192;
	s->data = (void *)"\
\x7f\x45\x4c\x46\x02\x01\x01\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\xd8\x18\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x0d\0\
\x0c\0\x79\x16\0\0\0\0\0\0\xbf\x63\0\0\0\0\0\0\x07\x03\0\0\x14\x08\0\0\xbf\xa1\
\0\0\0\0\0\0\x07\x01\0\0\x80\xff\xff\xff\xb7\x02\0\0\x04\0\0\0\x85\0\0\0\x04\0\
\0\0\x61\xa7\x80\xff\0\0\0\0\xbf\x63\0\0\0\0\0\0\x07\x03\0\0\x10\x08\0\0\xbf\
\xa1\0\0\0\0\0\0\x07\x01\0\0\x80\xff\xff\xff\xb7\x02\0\0\x04\0\0\0\x85\0\0\0\
\x04\0\0\0\x61\xa9\x80\xff\0\0\0\0\x1d\x79\x75\0\0\0\0\0\x63\x7a\x80\xff\0\0\0\
\0\xbf\xa2\0\0\0\0\0\0\x07\x02\0\0\x80\xff\xff\xff\x18\x01\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\x85\0\0\0\x01\0\0\0\x15\0\x6e\0\0\0\0\0\x63\x9a\x80\xff\0\0\0\0\xbf\
\xa2\0\0\0\0\0\0\x07\x02\0\0\x80\xff\xff\xff\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x85\0\0\0\x01\0\0\0\x55\0\x67\0\0\0\0\0\xb7\x08\0\0\0\0\0\0\x7b\x8a\x90\xff\
\0\0\0\0\x7b\x8a\xe0\xff\0\0\0\0\x7b\x8a\xd8\xff\0\0\0\0\x7b\x8a\xd0\xff\0\0\0\
\0\x7b\x8a\xc8\xff\0\0\0\0\x7b\x8a\xc0\xff\0\0\0\0\x7b\x8a\xb8\xff\0\0\0\0\x7b\
\x8a\xb0\xff\0\0\0\0\x7b\x8a\xa8\xff\0\0\0\0\x7b\x8a\xa0\xff\0\0\0\0\x7b\x8a\
\x98\xff\0\0\0\0\x7b\x8a\x88\xff\0\0\0\0\x7b\x8a\x80\xff\0\0\0\0\x63\x9a\x94\
\xff\0\0\0\0\x63\x7a\x90\xff\0\0\0\0\xbf\x63\0\0\0\0\0\0\x07\x03\0\0\x28\x08\0\
\0\xbf\xa1\0\0\0\0\0\0\x07\x01\0\0\xf0\xff\xff\xff\xb7\x02\0\0\x08\0\0\0\x85\0\
\0\0\x04\0\0\0\x79\xa3\xf0\xff\0\0\0\0\x15\x03\x07\0\0\0\0\0\x07\x03\0\0\x10\
\x08\0\0\xbf\xa1\0\0\0\0\0\0\x07\x01\0\0\xf0\xff\xff\xff\xb7\x02\0\0\x04\0\0\0\
\x85\0\0\0\x04\0\0\0\x61\xa1\xf0\xff\0\0\0\0\x63\x1a\x98\xff\0\0\0\0\xbf\x63\0\
\0\0\0\0\0\x07\x03\0\0\x78\x08\0\0\xbf\xa1\0\0\0\0\0\0\x07\x01\0\0\xf0\xff\xff\
\xff\xb7\x02\0\0\x08\0\0\0\x85\0\0\0\x04\0\0\0\x79\xa7\xf0\xff\0\0\0\0\x15\x07\
\x12\0\0\0\0\0\xbf\x73\0\0\0\0\0\0\x07\x03\0\0\x04\0\0\0\xbf\xa1\0\0\0\0\0\0\
\x07\x01\0\0\xf0\xff\xff\xff\xb7\x02\0\0\x04\0\0\0\x85\0\0\0\x04\0\0\0\x61\xa1\
\xf0\xff\0\0\0\0\x67\x01\0\0\x20\0\0\0\xc7\x01\0\0\x20\0\0\0\x67\x01\0\0\x04\0\
\0\0\x0f\x17\0\0\0\0\0\0\x07\x07\0\0\x60\0\0\0\xbf\xa1\0\0\0\0\0\0\x07\x01\0\0\
\xf0\xff\xff\xff\xb7\x02\0\0\x10\0\0\0\xbf\x73\0\0\0\0\0\0\x85\0\0\0\x04\0\0\0\
\x79\xa8\xf8\xff\0\0\0\0\x07\x06\0\0\x60\x0a\0\0\xbf\xa1\0\0\0\0\0\0\x07\x01\0\
\0\xf0\xff\xff\xff\xb7\x02\0\0\x08\0\0\0\xbf\x63\0\0\0\0\0\0\x85\0\0\0\x04\0\0\
\0\x79\xa3\xf0\xff\0\0\0\0\xb7\x01\0\0\0\0\0\0\x7b\x1a\xe8\xff\0\0\0\0\x07\x03\
\0\0\x90\x01\0\0\xbf\xa1\0\0\0\0\0\0\x07\x01\0\0\xe8\xff\xff\xff\xb7\x02\0\0\
\x08\0\0\0\x85\0\0\0\x04\0\0\0\x79\xa3\xe8\xff\0\0\0\0\x07\x03\0\0\x04\0\0\0\
\xbf\xa1\0\0\0\0\0\0\x07\x01\0\0\xf0\xff\xff\xff\xb7\x02\0\0\x04\0\0\0\x85\0\0\
\0\x04\0\0\0\x61\xa1\xf0\xff\0\0\0\0\x67\x01\0\0\x20\0\0\0\xc7\x01\0\0\x20\0\0\
\0\x67\x01\0\0\x04\0\0\0\x79\xa3\xe8\xff\0\0\0\0\x0f\x13\0\0\0\0\0\0\x07\x03\0\
\0\x60\0\0\0\xbf\xa1\0\0\0\0\0\0\x07\x01\0\0\xf0\xff\xff\xff\xb7\x02\0\0\x10\0\
\0\0\x85\0\0\0\x04\0\0\0\x61\xa1\xf0\xff\0\0\0\0\x79\xa2\xf8\xff\0\0\0\0\x1d\
\x82\x01\0\0\0\0\0\xb7\x01\0\0\0\0\0\0\x63\x1a\x9c\xff\0\0\0\0\x61\xa1\x94\xff\
\0\0\0\0\x63\x1a\xf0\xff\0\0\0\0\xbf\xa2\0\0\0\0\0\0\x07\x02\0\0\xf0\xff\xff\
\xff\xbf\xa3\0\0\0\0\0\0\x07\x03\0\0\x80\xff\xff\xff\x18\x01\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\xb7\x04\0\0\0\0\0\0\x85\0\0\0\x02\0\0\0\x95\0\0\0\0\0\0\0\x01\0\0\0\
\x10\0\0\0\x30\0\0\0\xe8\x03\0\0\0\0\0\0\x01\0\0\0\x08\0\0\0\x04\0\0\0\x64\0\0\
\0\0\0\0\0\x01\0\0\0\x08\0\0\0\x04\0\0\0\x64\0\0\0\0\0\0\0\x01\0\0\0\x04\0\0\0\
\x04\0\0\0\xe8\x03\0\0\0\0\0\0\x02\0\0\0\x04\0\0\0\x10\0\0\0\x01\0\0\0\0\0\0\0\
\x01\0\0\0\x04\0\0\0\x68\0\0\0\xe8\x03\0\0\0\0\0\0\x01\0\0\0\x04\0\0\0\xd8\x01\
\0\0\xe8\x03\0\0\0\0\0\0\x04\0\0\0\x04\0\0\0\x04\0\0\0\x40\0\0\0\0\0\0\0\x47\
\x50\x4c\0\x9f\xeb\x01\0\x18\0\0\0\0\0\0\0\x1c\x02\0\0\x1c\x02\0\0\x13\x07\0\0\
\0\0\0\0\0\0\0\x02\x02\0\0\0\x01\0\0\0\x01\0\0\x04\0\0\0\0\x19\0\0\0\x05\0\0\0\
\0\0\0\0\x1e\0\0\0\0\0\0\x08\x04\0\0\0\x24\0\0\0\0\0\0\x01\x08\0\0\0\x40\0\0\0\
\0\0\0\0\0\0\0\x03\0\0\0\0\x03\0\0\0\x06\0\0\0\0\0\0\0\x3b\0\0\0\0\0\0\x01\x04\
\0\0\0\x20\0\0\0\0\0\0\0\x01\0\0\x0d\0\0\0\0\x4f\0\0\0\x01\0\0\0\x53\0\0\0\x01\
\0\0\x0c\x07\0\0\0\x46\x06\0\0\x05\0\0\x04\x14\0\0\0\x52\x06\0\0\x0a\0\0\0\0\0\
\0\0\x57\x06\0\0\x0a\0\0\0\x20\0\0\0\x60\x06\0\0\x0a\0\0\0\x40\0\0\0\x6b\x06\0\
\0\x0a\0\0\0\x60\0\0\0\x77\x06\0\0\x0a\0\0\0\x80\0\0\0\x81\x06\0\0\0\0\0\x01\
\x04\0\0\0\x20\0\0\0\x8e\x06\0\0\0\0\0\x0e\x09\0\0\0\x01\0\0\0\xa0\x06\0\0\0\0\
\0\x0e\x09\0\0\0\x01\0\0\0\xad\x06\0\0\0\0\0\x0e\x09\0\0\0\x01\0\0\0\xb8\x06\0\
\0\0\0\0\x0e\x09\0\0\0\x01\0\0\0\xc5\x06\0\0\0\0\0\x0e\x09\0\0\0\x01\0\0\0\xce\
\x06\0\0\0\0\0\x0e\x09\0\0\0\x01\0\0\0\xdb\x06\0\0\0\0\0\x0e\x09\0\0\0\x01\0\0\
\0\xe6\x06\0\0\0\0\0\x0e\x09\0\0\0\x01\0\0\0\xf6\x06\0\0\0\0\0\x01\x01\0\0\0\
\x08\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\x13\0\0\0\x06\0\0\0\x04\0\0\0\xfb\x06\0\
\0\0\0\0\x0e\x14\0\0\0\x01\0\0\0\x06\x07\0\0\x01\0\0\x0f\0\0\0\0\x15\0\0\0\0\0\
\0\0\x04\0\0\0\x0e\x07\0\0\x08\0\0\x0f\0\0\0\0\x0b\0\0\0\0\0\0\0\x14\0\0\0\x0c\
\0\0\0\0\0\0\0\x14\0\0\0\x0d\0\0\0\0\0\0\0\x14\0\0\0\x0e\0\0\0\0\0\0\0\x14\0\0\
\0\x0f\0\0\0\0\0\0\0\x14\0\0\0\x10\0\0\0\0\0\0\0\x14\0\0\0\x11\0\0\0\0\0\0\0\
\x14\0\0\0\x12\0\0\0\0\0\0\0\x14\0\0\0\0\x62\x70\x66\x5f\x72\x61\x77\x5f\x74\
\x72\x61\x63\x65\x70\x6f\x69\x6e\x74\x5f\x61\x72\x67\x73\0\x61\x72\x67\x73\0\
\x5f\x5f\x75\x36\x34\0\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\x67\x20\x75\x6e\x73\x69\
\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x5f\x5f\x41\x52\x52\x41\x59\x5f\x53\x49\x5a\
\x45\x5f\x54\x59\x50\x45\x5f\x5f\0\x63\x74\x78\0\x62\x70\x66\x5f\x72\x61\x77\
\x5f\x74\x72\x61\x63\x65\x5f\x73\x63\x68\x65\x64\x5f\x77\x61\x6b\x65\x75\x70\
\x5f\x6e\x65\x77\0\x72\x61\x77\x5f\x74\x72\x61\x63\x65\x70\x6f\x69\x6e\x74\x2f\
\x73\x63\x68\x65\x64\x5f\x77\x61\x6b\x65\x75\x70\x5f\x6e\x65\x77\0\x2f\x62\x75\
\x69\x6c\x64\x64\x69\x72\x2f\x72\x70\x6d\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\
\x4c\x44\x2f\x67\x61\x6c\x61\x2d\x67\x6f\x70\x68\x65\x72\x2d\x31\x2e\x30\x2e\
\x31\x2f\x73\x72\x63\x2f\x70\x72\x6f\x62\x65\x73\x2f\x65\x78\x74\x65\x6e\x64\
\x73\x2f\x65\x62\x70\x66\x2e\x70\x72\x6f\x62\x65\x2f\x73\x72\x63\x2f\x74\x61\
\x73\x6b\x70\x72\x6f\x62\x65\x2f\x74\x68\x72\x65\x61\x64\x2e\x62\x70\x66\x2e\
\x63\0\x20\x20\x20\x20\x73\x74\x72\x75\x63\x74\x20\x74\x61\x73\x6b\x5f\x73\x74\
\x72\x75\x63\x74\x2a\x20\x74\x61\x73\x6b\x20\x3d\x20\x28\x73\x74\x72\x75\x63\
\x74\x20\x74\x61\x73\x6b\x5f\x73\x74\x72\x75\x63\x74\x2a\x29\x63\x74\x78\x2d\
\x3e\x61\x72\x67\x73\x5b\x30\x5d\x3b\0\x20\x20\x20\x20\x74\x67\x69\x64\x20\x3d\
\x20\x5f\x28\x74\x61\x73\x6b\x2d\x3e\x74\x67\x69\x64\x29\x3b\0\x20\x20\x20\x20\
\x70\x69\x64\x20\x3d\x20\x5f\x28\x74\x61\x73\x6b\x2d\x3e\x70\x69\x64\x29\x3b\0\
\x20\x20\x20\x20\x69\x66\x20\x28\x70\x69\x64\x20\x3d\x3d\x20\x74\x67\x69\x64\
\x29\x20\x7b\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x72\x70\x6d\x62\x75\x69\
\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x67\x61\x6c\x61\x2d\x67\x6f\x70\x68\x65\
\x72\x2d\x31\x2e\x30\x2e\x31\x2f\x73\x72\x63\x2f\x70\x72\x6f\x62\x65\x73\x2f\
\x65\x78\x74\x65\x6e\x64\x73\x2f\x65\x62\x70\x66\x2e\x70\x72\x6f\x62\x65\x2f\
\x73\x72\x63\x2f\x74\x61\x73\x6b\x70\x72\x6f\x62\x65\x2f\x2e\x2f\x70\x72\x6f\
\x63\x5f\x6d\x61\x70\x2e\x68\0\x20\x20\x20\x20\x72\x65\x74\x75\x72\x6e\x20\x28\
\x73\x74\x72\x75\x63\x74\x20\x70\x72\x6f\x63\x5f\x64\x61\x74\x61\x5f\x73\x20\
\x2a\x29\x62\x70\x66\x5f\x6d\x61\x70\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\
\x65\x6d\x28\x26\x67\x5f\x70\x72\x6f\x63\x5f\x6d\x61\x70\x2c\x20\x26\x70\x72\
\x6f\x63\x5f\x69\x64\x29\x3b\0\x20\x20\x20\x20\x69\x66\x20\x28\x67\x65\x74\x5f\
\x70\x72\x6f\x63\x5f\x65\x6e\x74\x72\x79\x28\x74\x67\x69\x64\x29\x20\x26\x26\
\x20\x21\x67\x65\x74\x5f\x74\x68\x72\x65\x61\x64\x28\x70\x69\x64\x29\x29\x20\
\x7b\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x72\x70\x6d\x62\x75\x69\x6c\x64\
\x2f\x42\x55\x49\x4c\x44\x2f\x67\x61\x6c\x61\x2d\x67\x6f\x70\x68\x65\x72\x2d\
\x31\x2e\x30\x2e\x31\x2f\x73\x72\x63\x2f\x70\x72\x6f\x62\x65\x73\x2f\x65\x78\
\x74\x65\x6e\x64\x73\x2f\x65\x62\x70\x66\x2e\x70\x72\x6f\x62\x65\x2f\x73\x72\
\x63\x2f\x74\x61\x73\x6b\x70\x72\x6f\x62\x65\x2f\x2e\x2f\x74\x68\x72\x65\x61\
\x64\x5f\x6d\x61\x70\x2e\x68\0\x20\x20\x20\x20\x72\x65\x74\x75\x72\x6e\x20\x28\
\x73\x74\x72\x75\x63\x74\x20\x74\x68\x72\x65\x61\x64\x5f\x64\x61\x74\x61\x20\
\x2a\x29\x62\x70\x66\x5f\x6d\x61\x70\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\
\x65\x6d\x28\x26\x67\x5f\x74\x68\x72\x65\x61\x64\x5f\x6d\x61\x70\x2c\x20\x26\
\x70\x69\x64\x29\x3b\0\x20\x20\x20\x20\x20\x20\x20\x20\x73\x74\x72\x75\x63\x74\
\x20\x74\x68\x72\x65\x61\x64\x5f\x64\x61\x74\x61\x20\x74\x68\x72\x20\x3d\x20\
\x7b\x30\x7d\x3b\0\x20\x20\x20\x20\x20\x20\x20\x20\x74\x68\x72\x2e\x69\x64\x2e\
\x70\x69\x64\x20\x3d\x20\x70\x69\x64\x3b\0\x20\x20\x20\x20\x20\x20\x20\x20\x74\
\x68\x72\x2e\x69\x64\x2e\x74\x67\x69\x64\x20\x3d\x20\x74\x67\x69\x64\x3b\0\x20\
\x20\x20\x20\x20\x20\x20\x20\x70\x61\x72\x65\x6e\x74\x20\x3d\x20\x5f\x28\x74\
\x61\x73\x6b\x2d\x3e\x70\x61\x72\x65\x6e\x74\x29\x3b\0\x20\x20\x20\x20\x20\x20\
\x20\x20\x69\x66\x20\x28\x70\x61\x72\x65\x6e\x74\x29\x20\x7b\0\x20\x20\x20\x20\
\x20\x20\x20\x20\x20\x20\x20\x20\x74\x68\x72\x2e\x69\x64\x2e\x70\x70\x69\x64\
\x20\x3d\x20\x5f\x28\x70\x61\x72\x65\x6e\x74\x2d\x3e\x70\x69\x64\x29\x3b\0\x20\
\x20\x20\x20\x73\x74\x72\x75\x63\x74\x20\x70\x69\x64\x20\x2a\x74\x68\x72\x65\
\x61\x64\x5f\x70\x69\x64\x20\x3d\x20\x5f\x28\x63\x75\x72\x5f\x74\x61\x73\x6b\
\x2d\x3e\x74\x68\x72\x65\x61\x64\x5f\x70\x69\x64\x29\x3b\0\x20\x20\x20\x20\x69\
\x66\x20\x28\x74\x68\x72\x65\x61\x64\x5f\x70\x69\x64\x20\x21\x3d\x20\x30\x29\
\x20\x7b\0\x20\x20\x20\x20\x20\x20\x20\x20\x69\x6e\x74\x20\x6c\x20\x3d\x20\x5f\
\x28\x74\x68\x72\x65\x61\x64\x5f\x70\x69\x64\x2d\x3e\x6c\x65\x76\x65\x6c\x29\
\x3b\0\x20\x20\x20\x20\x20\x20\x20\x20\x73\x74\x72\x75\x63\x74\x20\x75\x70\x69\
\x64\x20\x74\x68\x72\x65\x61\x64\x5f\x75\x70\x69\x64\x20\x3d\x20\x5f\x28\x74\
\x68\x72\x65\x61\x64\x5f\x70\x69\x64\x2d\x3e\x6e\x75\x6d\x62\x65\x72\x73\x5b\
\x6c\x5d\x29\x3b\0\x20\x20\x20\x20\x73\x74\x72\x75\x63\x74\x20\x73\x69\x67\x6e\
\x61\x6c\x5f\x73\x74\x72\x75\x63\x74\x2a\x20\x73\x69\x67\x6e\x61\x6c\x20\x3d\
\x20\x5f\x28\x63\x75\x72\x5f\x74\x61\x73\x6b\x2d\x3e\x73\x69\x67\x6e\x61\x6c\
\x29\x3b\0\x20\x20\x20\x20\x73\x74\x72\x75\x63\x74\x20\x70\x69\x64\x20\x2a\x70\
\x69\x64\x5f\x70\x20\x3d\x20\x28\x73\x74\x72\x75\x63\x74\x20\x70\x69\x64\x20\
\x2a\x29\x30\x3b\0\x20\x20\x20\x20\x62\x70\x66\x5f\x70\x72\x6f\x62\x65\x5f\x72\
\x65\x61\x64\x28\x26\x70\x69\x64\x5f\x70\x2c\x20\x73\x69\x7a\x65\x6f\x66\x28\
\x73\x74\x72\x75\x63\x74\x20\x70\x69\x64\x20\x2a\x29\x2c\x20\x26\x73\x69\x67\
\x6e\x61\x6c\x2d\x3e\x70\x69\x64\x73\x5b\x50\x49\x44\x54\x59\x50\x45\x5f\x50\
\x47\x49\x44\x5d\x29\x3b\0\x20\x20\x20\x20\x69\x6e\x74\x20\x6c\x65\x76\x65\x6c\
\x20\x3d\x20\x5f\x28\x70\x69\x64\x5f\x70\x2d\x3e\x6c\x65\x76\x65\x6c\x29\x3b\0\
\x20\x20\x20\x20\x73\x74\x72\x75\x63\x74\x20\x75\x70\x69\x64\x20\x75\x70\x69\
\x64\x20\x3d\x20\x5f\x28\x70\x69\x64\x5f\x70\x2d\x3e\x6e\x75\x6d\x62\x65\x72\
\x73\x5b\x6c\x65\x76\x65\x6c\x5d\x29\x3b\0\x20\x20\x20\x20\x69\x66\x20\x28\x75\
\x70\x69\x64\x2e\x6e\x73\x20\x3d\x3d\x20\x6e\x73\x5f\x69\x6e\x66\x6f\x29\x20\
\x7b\0\x20\x20\x20\x20\x20\x20\x20\x20\x74\x68\x72\x2e\x69\x64\x2e\x70\x67\x69\
\x64\x20\x3d\x20\x67\x65\x74\x5f\x74\x61\x73\x6b\x5f\x70\x67\x69\x64\x28\x74\
\x61\x73\x6b\x29\x3b\0\x20\x20\x20\x20\x20\x20\x20\x20\x28\x76\x6f\x69\x64\x29\
\x74\x68\x72\x65\x61\x64\x5f\x61\x64\x64\x28\x74\x68\x72\x2e\x69\x64\x2e\x70\
\x69\x64\x2c\x20\x26\x74\x68\x72\x29\x3b\0\x20\x20\x20\x20\x72\x65\x74\x75\x72\
\x6e\x20\x62\x70\x66\x5f\x6d\x61\x70\x5f\x75\x70\x64\x61\x74\x65\x5f\x65\x6c\
\x65\x6d\x28\x26\x67\x5f\x74\x68\x72\x65\x61\x64\x5f\x6d\x61\x70\x2c\x20\x26\
\x70\x69\x64\x2c\x20\x64\x61\x74\x61\x2c\x20\x42\x50\x46\x5f\x41\x4e\x59\x29\
\x3b\0\x7d\0\x62\x70\x66\x5f\x6d\x61\x70\x5f\x64\x65\x66\0\x74\x79\x70\x65\0\
\x6b\x65\x79\x5f\x73\x69\x7a\x65\0\x76\x61\x6c\x75\x65\x5f\x73\x69\x7a\x65\0\
\x6d\x61\x78\x5f\x65\x6e\x74\x72\x69\x65\x73\0\x6d\x61\x70\x5f\x66\x6c\x61\x67\
\x73\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x5f\x5f\x70\x72\x6f\
\x62\x65\x5f\x6d\x61\x74\x63\x68\x5f\x6d\x61\x70\0\x63\x67\x72\x70\x5f\x6f\x62\
\x6a\x5f\x6d\x61\x70\0\x6e\x6d\x5f\x6f\x62\x6a\x5f\x6d\x61\x70\0\x70\x72\x6f\
\x63\x5f\x6f\x62\x6a\x5f\x6d\x61\x70\0\x61\x72\x67\x73\x5f\x6d\x61\x70\0\x67\
\x5f\x74\x68\x72\x65\x61\x64\x5f\x6d\x61\x70\0\x67\x5f\x70\x72\x6f\x63\x5f\x6d\
\x61\x70\0\x67\x5f\x74\x68\x72\x65\x61\x64\x5f\x6f\x75\x74\x70\x75\x74\0\x63\
\x68\x61\x72\0\x67\x5f\x6c\x69\x6e\x73\x65\x6e\x63\x65\0\x6c\x69\x63\x65\x6e\
\x73\x65\0\x6d\x61\x70\x73\0\x9f\xeb\x01\0\x20\0\0\0\0\0\0\0\x14\0\0\0\x14\0\0\
\0\x6c\x03\0\0\x80\x03\0\0\0\0\0\0\x08\0\0\0\x72\0\0\0\x01\0\0\0\0\0\0\0\x08\0\
\0\0\x10\0\0\0\x72\0\0\0\x36\0\0\0\0\0\0\0\x92\0\0\0\xf6\0\0\0\x35\xe4\0\0\x08\
\0\0\0\x92\0\0\0\x38\x01\0\0\x0c\xec\0\0\x20\0\0\0\x92\0\0\0\0\0\0\0\0\0\0\0\
\x28\0\0\0\x92\0\0\0\x38\x01\0\0\x0c\xec\0\0\x40\0\0\0\x92\0\0\0\x52\x01\0\0\
\x0b\xf0\0\0\x58\0\0\0\x92\0\0\0\0\0\0\0\0\0\0\0\x60\0\0\0\x92\0\0\0\x52\x01\0\
\0\x0b\xf0\0\0\x78\0\0\0\x92\0\0\0\x6a\x01\0\0\x09\xf4\0\0\x90\0\0\0\x81\x01\0\
\0\0\0\0\0\0\0\0\0\x98\0\0\0\x81\x01\0\0\xe5\x01\0\0\x22\x8c\0\0\xb0\0\0\0\x92\
\0\0\0\x32\x02\0\0\x1e\0\x01\0\xc8\0\0\0\x66\x02\0\0\0\0\0\0\0\0\0\0\xd0\0\0\0\
\x66\x02\0\0\xcc\x02\0\0\x22\x8c\0\0\xe8\0\0\0\x92\0\0\0\x32\x02\0\0\x09\0\x01\
\0\xf8\0\0\0\x92\0\0\0\x17\x03\0\0\x1c\x04\x01\0\x60\x01\0\0\x92\0\0\0\x3d\x03\
\0\0\x14\x08\x01\0\x68\x01\0\0\x92\0\0\0\x57\x03\0\0\x15\x0c\x01\0\x70\x01\0\0\
\x92\0\0\0\x73\x03\0\0\x12\x10\x01\0\x88\x01\0\0\x92\0\0\0\x17\x03\0\0\x1c\x04\
\x01\0\x90\x01\0\0\x92\0\0\0\x73\x03\0\0\x12\x10\x01\0\xa8\x01\0\0\x92\0\0\0\
\x95\x03\0\0\x0d\x14\x01\0\xb0\x01\0\0\x92\0\0\0\xab\x03\0\0\x1b\x18\x01\0\xc0\
\x01\0\0\x92\0\0\0\0\0\0\0\0\0\0\0\xc8\x01\0\0\x92\0\0\0\xab\x03\0\0\x1b\x18\
\x01\0\xe0\x01\0\0\x92\0\0\0\xab\x03\0\0\x19\x18\x01\0\xe8\x01\0\0\x92\0\0\0\
\xd5\x03\0\0\x1e\x80\0\0\0\x02\0\0\x92\0\0\0\0\0\0\0\0\0\0\0\x08\x02\0\0\x92\0\
\0\0\xd5\x03\0\0\x1e\x80\0\0\x20\x02\0\0\x92\0\0\0\x0b\x04\0\0\x09\x88\0\0\x28\
\x02\0\0\x92\0\0\0\x26\x04\0\0\x11\x8c\0\0\x40\x02\0\0\x92\0\0\0\0\0\0\0\0\0\0\
\0\x48\x02\0\0\x92\0\0\0\x26\x04\0\0\x11\x8c\0\0\x70\x02\0\0\x92\0\0\0\x4c\x04\
\0\0\x23\x90\0\0\x90\x02\0\0\x92\0\0\0\0\0\0\0\0\0\0\0\x98\x02\0\0\x92\0\0\0\
\x4c\x04\0\0\x23\x90\0\0\xb8\x02\0\0\x92\0\0\0\x89\x04\0\0\x24\xa4\0\0\xc8\x02\
\0\0\x92\0\0\0\0\0\0\0\0\0\0\0\xd0\x02\0\0\x92\0\0\0\x89\x04\0\0\x24\xa4\0\0\
\xf8\x02\0\0\x92\0\0\0\xc1\x04\0\0\x11\xa8\0\0\0\x03\0\0\x92\0\0\0\xea\x04\0\0\
\x33\xac\0\0\x10\x03\0\0\x92\0\0\0\0\0\0\0\0\0\0\0\x18\x03\0\0\x92\0\0\0\xea\
\x04\0\0\x05\xac\0\0\x28\x03\0\0\x92\0\0\0\x39\x05\0\0\x11\xb0\0\0\x40\x03\0\0\
\x92\0\0\0\0\0\0\0\0\0\0\0\x48\x03\0\0\x92\0\0\0\x39\x05\0\0\x11\xb0\0\0\x70\
\x03\0\0\x92\0\0\0\x5a\x05\0\0\x18\xb4\0\0\x98\x03\0\0\x92\0\0\0\0\0\0\0\0\0\0\
\0\xa0\x03\0\0\x92\0\0\0\x5a\x05\0\0\x18\xb4\0\0\xc0\x03\0\0\x92\0\0\0\x8b\x05\
\0\0\x09\xb8\0\0\xd0\x03\0\0\x92\0\0\0\xa9\x05\0\0\x15\x20\x01\0\xd8\x03\0\0\
\x92\0\0\0\xd4\x05\0\0\x21\x24\x01\0\xf0\x03\0\0\x92\0\0\0\0\0\0\0\0\0\0\0\x08\
\x04\0\0\x66\x02\0\0\0\x06\0\0\x0c\xa0\0\0\x28\x04\0\0\x92\0\0\0\x44\x06\0\0\
\x01\x2c\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x13\
\x01\0\0\0\0\x02\0\x28\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0c\x01\0\0\0\0\x02\0\
\xe8\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x05\x01\0\0\0\0\x02\0\xb8\x02\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\xfe\0\0\0\0\0\x02\0\xd0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x03\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x9a\0\0\0\x11\0\x03\0\0\0\0\0\0\
\0\0\0\x14\0\0\0\0\0\0\0\x6c\0\0\0\x11\0\x03\0\x50\0\0\0\0\0\0\0\x14\0\0\0\0\0\
\0\0\x01\0\0\0\x12\0\x02\0\0\0\0\0\0\0\0\0\x30\x04\0\0\0\0\0\0\x75\0\0\0\x11\0\
\x03\0\x14\0\0\0\0\0\0\0\x14\0\0\0\0\0\0\0\xda\0\0\0\x11\0\x04\0\0\0\0\0\0\0\0\
\0\x04\0\0\0\0\0\0\0\xb9\0\0\0\x11\0\x03\0\x78\0\0\0\0\0\0\0\x14\0\0\0\0\0\0\0\
\xac\0\0\0\x11\0\x03\0\x64\0\0\0\0\0\0\0\x14\0\0\0\0\0\0\0\x57\0\0\0\x11\0\x03\
\0\x8c\0\0\0\0\0\0\0\x14\0\0\0\0\0\0\0\x82\0\0\0\x11\0\x03\0\x28\0\0\0\0\0\0\0\
\x14\0\0\0\0\0\0\0\x8d\0\0\0\x11\0\x03\0\x3c\0\0\0\0\0\0\0\x14\0\0\0\0\0\0\0\
\x98\0\0\0\0\0\0\0\x01\0\0\0\x0b\0\0\0\xd0\0\0\0\0\0\0\0\x01\0\0\0\x0c\0\0\0\
\x08\x04\0\0\0\0\0\0\x01\0\0\0\x0c\0\0\0\xc0\x01\0\0\0\0\0\0\0\0\0\0\x0a\0\0\0\
\xd8\x01\0\0\0\0\0\0\0\0\0\0\x06\0\0\0\xe4\x01\0\0\0\0\0\0\0\0\0\0\x09\0\0\0\
\xf0\x01\0\0\0\0\0\0\0\0\0\0\x0e\0\0\0\xfc\x01\0\0\0\0\0\0\0\0\0\0\x0f\0\0\0\
\x08\x02\0\0\0\0\0\0\0\0\0\0\x07\0\0\0\x14\x02\0\0\0\0\0\0\0\0\0\0\x0c\0\0\0\
\x20\x02\0\0\0\0\0\0\0\0\0\0\x0b\0\0\0\x2c\x02\0\0\0\0\0\0\0\0\0\0\x0d\0\0\0\
\x2c\0\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x50\0\
\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x60\0\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x70\0\0\0\0\
\0\0\0\0\0\0\0\x05\0\0\0\x80\0\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x90\0\0\0\0\0\0\0\
\0\0\0\0\x05\0\0\0\xa0\0\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\xb0\0\0\0\0\0\0\0\0\0\0\
\0\x05\0\0\0\xc0\0\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\xd0\0\0\0\0\0\0\0\0\0\0\0\x05\
\0\0\0\xe0\0\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\xf0\0\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\
\0\x01\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x10\x01\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x20\
\x01\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x30\x01\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x40\
\x01\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x50\x01\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x60\
\x01\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x70\x01\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x80\
\x01\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x90\x01\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\xa0\
\x01\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\xb0\x01\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\xc0\
\x01\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\xd0\x01\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\xe0\
\x01\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\xf0\x01\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\0\x02\
\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x10\x02\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x20\x02\0\
\0\0\0\0\0\0\0\0\0\x05\0\0\0\x30\x02\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x40\x02\0\0\
\0\0\0\0\0\0\0\0\x05\0\0\0\x50\x02\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x60\x02\0\0\0\
\0\0\0\0\0\0\0\x05\0\0\0\x70\x02\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x80\x02\0\0\0\0\
\0\0\0\0\0\0\x05\0\0\0\x90\x02\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\xa0\x02\0\0\0\0\0\
\0\0\0\0\0\x05\0\0\0\xb0\x02\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\xc0\x02\0\0\0\0\0\0\
\0\0\0\0\x05\0\0\0\xd0\x02\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\xe0\x02\0\0\0\0\0\0\0\
\0\0\0\x05\0\0\0\xf0\x02\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\
\0\x05\0\0\0\x10\x03\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x20\x03\0\0\0\0\0\0\0\0\0\0\
\x05\0\0\0\x30\x03\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x40\x03\0\0\0\0\0\0\0\0\0\0\
\x05\0\0\0\x50\x03\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x60\x03\0\0\0\0\0\0\0\0\0\0\
\x05\0\0\0\x70\x03\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x80\x03\0\0\0\0\0\0\0\0\0\0\
\x05\0\0\0\x90\x03\0\0\0\0\0\0\0\0\0\0\x05\0\0\0\x0f\x0d\x10\x15\x16\x0e\x13\
\x12\x14\x11\0\x62\x70\x66\x5f\x72\x61\x77\x5f\x74\x72\x61\x63\x65\x5f\x73\x63\
\x68\x65\x64\x5f\x77\x61\x6b\x65\x75\x70\x5f\x6e\x65\x77\0\x2e\x72\x65\x6c\x72\
\x61\x77\x5f\x74\x72\x61\x63\x65\x70\x6f\x69\x6e\x74\x2f\x73\x63\x68\x65\x64\
\x5f\x77\x61\x6b\x65\x75\x70\x5f\x6e\x65\x77\0\x2e\x74\x65\x78\x74\0\x2e\x72\
\x65\x6c\x2e\x42\x54\x46\x2e\x65\x78\x74\0\x67\x5f\x74\x68\x72\x65\x61\x64\x5f\
\x6f\x75\x74\x70\x75\x74\0\x6d\x61\x70\x73\0\x61\x72\x67\x73\x5f\x6d\x61\x70\0\
\x63\x67\x72\x70\x5f\x6f\x62\x6a\x5f\x6d\x61\x70\0\x6e\x6d\x5f\x6f\x62\x6a\x5f\
\x6d\x61\x70\0\x70\x72\x6f\x63\x5f\x6f\x62\x6a\x5f\x6d\x61\x70\0\x5f\x5f\x70\
\x72\x6f\x62\x65\x5f\x6d\x61\x74\x63\x68\x5f\x6d\x61\x70\0\x67\x5f\x74\x68\x72\
\x65\x61\x64\x5f\x6d\x61\x70\0\x67\x5f\x70\x72\x6f\x63\x5f\x6d\x61\x70\0\x2e\
\x6c\x6c\x76\x6d\x5f\x61\x64\x64\x72\x73\x69\x67\0\x6c\x69\x63\x65\x6e\x73\x65\
\0\x67\x5f\x6c\x69\x6e\x73\x65\x6e\x63\x65\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\
\x73\x79\x6d\x74\x61\x62\0\x2e\x72\x65\x6c\x2e\x42\x54\x46\0\x4c\x42\x42\x30\
\x5f\x39\0\x4c\x42\x42\x30\x5f\x37\0\x4c\x42\x42\x30\x5f\x35\0\x4c\x42\x42\x30\
\x5f\x31\x30\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x44\0\0\
\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x24\0\0\0\x01\0\0\0\x06\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\x30\x04\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x67\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x70\x04\0\0\0\0\0\0\xa0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\xd2\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x10\x05\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\xf9\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x14\x05\0\0\0\0\
\0\0\x47\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x4e\
\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x5b\x0e\0\0\0\0\0\0\xa0\x03\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xed\0\0\0\x02\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x12\0\0\0\0\0\0\x80\x01\0\0\0\0\0\0\x0c\0\
\0\0\x06\0\0\0\x08\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\0\x20\0\0\0\x09\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x80\x13\0\0\0\0\0\0\x30\0\0\0\0\0\0\0\x07\0\0\0\x02\0\
\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\xf5\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\xb0\x13\0\0\0\0\0\0\x90\0\0\0\0\0\0\0\x07\0\0\0\x05\0\0\0\x08\0\
\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x4a\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x40\x14\0\0\0\0\0\0\x70\x03\0\0\0\0\0\0\x07\0\0\0\x06\0\0\0\x08\0\0\0\0\0\
\0\0\x10\0\0\0\0\0\0\0\xc4\0\0\0\x03\x4c\xff\x6f\0\0\0\x80\0\0\0\0\0\0\0\0\0\0\
\0\0\xb0\x17\0\0\0\0\0\0\x0a\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\xe5\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xba\x17\0\0\
\0\0\0\0\x1b\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0";

	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return -1;
}

#endif /* __THREAD_BPF_SKEL_H__ */
